@@ -1,37 +1,41 @@
-const TARGET_EXE_PATH: &'static str = env!("CARGO_BIN_EXE_aki-stats");
+const TARGET_EXE_PATH: &'static str = env!(concat!("CARGO_BIN_EXE_", env!("CARGO_PKG_NAME")));
 
 macro_rules! help_msg {
     () => {
         concat!(
             version_msg!(),
             "\n",
-            "Usage:\n",
-            "  aki-stats [options]\n",
-            "\n",
-            "output the statistics of text, like a wc of linux command.\n",
-            "\n",
-            "Options:\n",
-            "  -a, --all                 output the all statistics of text, exclude ascii map\n",
-            "  -b, --bytes               output the byte counts\n",
-            "  -c, --chars               output the unicode character counts\n",
-            "  -l, --lines               output the line counts\n",
-            "      --map-ascii           output the ascii map statistics\n",
-            "  -m, --max-line-bytes      output the maximum byte counts of line\n",
-            "  -w, --words               output the word counts\n",
-            "      --locale <loc>        locale of number format: en, fr, ... posix\n",
-            "  -?, --query <q>           display available names of locale and exit\n",
-            "\n",
-            "  -H, --help        display this help and exit\n",
-            "  -V, --version     display version information and exit\n",
-            "  -X <x-options>    x options. try -X help\n",
-            "\n",
-            "Examples:\n",
-            "  Outputs the line count:\n",
-            "    echo -e \"acbde fghi\\njkln opqr\" | aki-stats -l\n",
-            "  Outputs the byte count:\n",
-            "    echo -e \"acbde fghi\\njkln opqr\" | aki-stats -b\n",
-            "  Outputs the word count:\n",
-            "    echo -e \"acbde fghi\\njkln opqr\" | aki-stats -w\n",
+            indoc::indoc!(
+                r#"
+            Usage:
+              aki-stats [options]
+
+            output the statistics of text, like a wc of linux command.
+
+            Options:
+              -a, --all                 output the all statistics of text, exclude ascii map
+              -b, --bytes               output the byte counts
+              -c, --chars               output the unicode character counts
+              -l, --lines               output the line counts
+                  --map-ascii           output the ascii map statistics
+              -m, --max-line-bytes      output the maximum byte counts of line
+              -w, --words               output the word counts
+                  --locale <loc>        locale of number format: en, fr, ... posix
+              -?, --query <q>           display available names of locale and exit
+
+              -H, --help        display this help and exit
+              -V, --version     display version information and exit
+              -X <x-options>    x options. try -X help
+
+            Examples:
+              Outputs the line count:
+                echo -e "acbde fghi\njkln opqr" | aki-stats -l
+              Outputs the byte count:
+                echo -e "acbde fghi\njkln opqr" | aki-stats -b
+              Outputs the word count:
+                echo -e "acbde fghi\njkln opqr" | aki-stats -w
+            "#
+            ),
             "\n",
         )
     };
@@ -55,10 +59,10 @@ macro_rules! version_msg {
     };
 }
 
-mod helper;
+//mod helper;
 
 mod test_0 {
-    use crate::helper::exec_target;
+    use exec_target::exec_target;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
     #[test]
@@ -137,7 +141,7 @@ A proposition which I took the liberty of doubting.
 ";
 
 mod test_1 {
-    use crate::helper::exec_target_with_in;
+    use exec_target::exec_target_with_in;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
     #[test]
@@ -193,7 +197,7 @@ mod test_1 {
 }
 
 mod test_2 {
-    use crate::helper::exec_target_with_in;
+    use exec_target::exec_target_with_in;
     const TARGET_EXE_PATH: &'static str = super::TARGET_EXE_PATH;
     //
     #[test]
